==> rest-assured-1.5-sources.jar: com/jayway/restassured/assertion/BodyMatcher.java <==
package com.jayway.restassured.assertion;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class BodyMatcher
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public BodyMatcher
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getKey() { return null;}
public  void setKey(java.lang.Object value) { }
public  org.hamcrest.Matcher getMatcher() { return (org.hamcrest.Matcher)null;}
public  void setMatcher(org.hamcrest.Matcher value) { }
public  com.jayway.restassured.internal.ResponseParserRegistrar getRpr() { return (com.jayway.restassured.internal.ResponseParserRegistrar)null;}
public  void setRpr(com.jayway.restassured.internal.ResponseParserRegistrar value) { }
public  java.lang.Object isFulfilled(com.jayway.restassured.response.Response response, java.lang.Object content) { return null;}
public  java.lang.Object fallbackToResponseBodyIfContentHasAlreadyBeenRead(com.jayway.restassured.response.Response response, java.lang.Object content) { return null;}
public  boolean requiresTextParsing() { return false;}
public  java.lang.String getDescription() { return (java.lang.String)null;}
}

==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/assertion/BodyMatcher.java <==
package com.jayway.restassured.assertion;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class BodyMatcher
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getKey() { return null;}
public  void setKey(java.lang.Object value) { }
public  org.hamcrest.Matcher getMatcher() { return (org.hamcrest.Matcher)null;}
public  void setMatcher(org.hamcrest.Matcher value) { }
public  com.jayway.restassured.internal.ResponseParserRegistrar getRpr() { return (com.jayway.restassured.internal.ResponseParserRegistrar)null;}
public  void setRpr(com.jayway.restassured.internal.ResponseParserRegistrar value) { }
public  java.lang.Object validate(com.jayway.restassured.response.Response response, java.lang.Object content) { return null;}
public  java.lang.Object fallbackToResponseBodyIfContentHasAlreadyBeenRead(com.jayway.restassured.response.Response response, java.lang.Object content) { return null;}
public  boolean requiresTextParsing() { return false;}
public  java.lang.String getDescription() { return (java.lang.String)null;}
}
